@@ -461,7 +461,7 @@ class NamedMatrix(object):
             if sourcecode is None or source is None or source in sourcecode:
                 if not values.has_key(name1):
                     values[name1] = dict()
-                if not values.has_key(name2):
+                if not values[name1].has_key(name2):
                     values[name1][name2] = list()
                 values[name1][name2].append( float(val) )
                 rownames[name1] = True
